"use client";

import Link from "next/link";
import { usePathname } from "next/navigation";

import { ChevronDown, User } from "lucide-react";
import { useSession } from "next-auth/react";

import {
	DropdownMenu,
	DropdownMenuContent,
	DropdownMenuItem,
	DropdownMenuTrigger,
} from "@/components/ui/dropdown-menu";
import { Locale } from "@/i18n/routing";
import { cn } from "@/lib/utils";

const navItems = [
	{ href: "/", label: { en: "Home", ar: "الرئيسية" } },
	{ href: "/history", label: { en: "History", ar: "تاريخنا" } },
	{
		href: "/services",
		label: { en: "Services", ar: "خدماتنا" },
		hasDropdown: true,
		hasHref: false,
		active: true,
		dropdownItems: [
			{ href: "services/1", label: { en: "Service 1", ar: "خدمة 1" } },
			{ href: "services/2", label: { en: "Service 2", ar: "خدمة 2" } },
			{ href: "services/3", label: { en: "Service 3", ar: "خدمة 3" } },
		],
	},
	{ href: "/projects", label: { en: "Projects", ar: "مشاريعنا" } },
	{ href: "/products", label: { en: "Products", ar: "منتجات" } },
	{ href: "/library", label: { en: "Library", ar: "المكتبة" } },
	{
		href: "/request-a-field-visit",
		label: { en: "Requests", ar: "الطلبات" },
		hasDropdown: true,
		active: true,
		dropdownItems: [
			{
				href: "request-a-field-visit",
				label: { en: "Request a field visit", ar: "طلب زيارة ميدانية" },
			},
			{
				href: "maintenance-request",
				label: { en: "Maintenance request", ar: "طلب صيانة" },
			},
			{
				href: "request-for-employment",
				label: { en: "Employment request", ar: "طلب توظيف" },
			},
		],
	},
];

export default function Navigation({ locale }: { locale: Locale }) {
	const pathname = usePathname();
	const currentPath = pathname;

	const { data: session, status } = useSession();

	return (
		<nav
			className={cn(
				"absolute -top-12 mx-auto mt-4 hidden h-[59px] w-full rounded-[5px] bg-[#2292CBF2] text-white lg:block",
				""
			)}
		>
			<div className="flex h-full flex-row items-center justify-between px-9">
				<ul className="z-[100000] flex flex-[70%] items-center gap-7">
					{navItems?.map((item: any, index) => {
						const isActive = currentPath === `/${locale}${item.href}`;
						return (
							<li key={index} className="relative">
								{item.hasDropdown ? (
									<DropdownMenu>
										<DropdownMenuTrigger
											className="flex items-center gap-1 hover:text-custom-tertiary"
										// onMouseEnter={() => setOpen(true)}
										// onMouseLeave={() => setOpen(false)}
										>
											{item.hasHref ? (
												<Link
													href={{
														pathname: `/${locale}${item.href}`,
													}}
													className="w-full"
												>
													{item.label?.[locale]}
												</Link>
											) : (
												item.label?.[locale]
											)}
											<ChevronDown className="size-4" />
										</DropdownMenuTrigger>
										<DropdownMenuContent align="end" className="w-48">
											{item.dropdownItems?.map((dropdownItem: any) => (
												<DropdownMenuItem
													key={dropdownItem.href}
													className={cn(
														locale == "ar" ? "text-end" : "text-start"
													)}
												>
													<Link
														href={{
															pathname: `/${locale}/${dropdownItem.href}`,
														}}
														className="w-full"
													>
														{dropdownItem.label?.[locale]}
													</Link>
												</DropdownMenuItem>
											))}
										</DropdownMenuContent>
									</DropdownMenu>
								) : (
									<Link
										href={{
											pathname: `/${locale}${item.href}`,
										}}
										className={cn(
											"relative py-2 text-base hover:text-custom-tertiary",
											isActive && "font-semibold"
										)}
									>
										{item.label?.[locale]}
										{isActive && (
											<span className="absolute bottom-0 left-1/2 mt-1 size-1.5 -translate-x-1/2 rounded-full bg-background" />
										)}
									</Link>
								)}
							</li>
						);
					})}
				</ul>
				<div className="flex flex-[30%] items-center justify-end gap-2">
					{status === "authenticated" ? (
						<div>
							<Link
								href={{ pathname: `/${locale}/user-account` }}
								className="flex items-center gap-2 text-sm hover:text-custom-tertiary"
							>
								<p>{session?.user?.name}</p>
								<User className="size-5" />
							</Link>
						</div>
					) : (
						<>
							<Link
								href={{ pathname: `/${locale}/login` }}
								className="flex items-center gap-2 text-sm hover:text-custom-tertiary"
							>
								{locale === "ar" ? "تسجيل دخول" : "Login"}
							</Link>
							<p className="mx-1">/</p>
							<Link
								href={{ pathname: `/${locale}/register` }}
								className="flex items-center gap-2 text-sm hover:text-custom-tertiary"
							>
								{locale === "ar" ? "تسجيل حساب" : "Register"}
							</Link>
						</>
					)}
				</div>
			</div>
		</nav>
	);
}
